import proxml.*;            // imports the proxml library

PFont font;                 // creates a new variable named font that holds a PFont object
SuperText[] allText;        // creates an array named allText that will store a list of SuperText objects
XMLInOut xml;               // creates a variable named xml that will hold an XMLInOut object

void setup() {
  font = loadFont("AGaramondPro-Bold-20.vlw");                            // loads the indicated font and stores it in the font variable
  textFont(font, 20);                                                     // sets the current font and size used to display text
  xml = new XMLInOut(this);                                               // initializes the new XMLInOut object
  xml.loadElement("http://santabarbara.craigslist.org/pet/index.rss");    // loads the root element found at the link given as the first parameter
  allText = new SuperText[0];                                             // initializes the array that will hold all of our SuperText objects
  size(500,500);
}

void xmlEvent(XMLElement e) {                                             // xmlEvent is an event handler that triggers actions when the root element has finished
                                                                          // downloading
  XMLElement[] children = e.getChildren();                                // Creates an array of XMLElements that holds all the children of the root element
  for(int i=1; i<children.length; i++) {                                  // loop through all the children starting with the second child (children[0] is the first)
    String linkText = children[i].firstChild().firstChild().getText();    // get the first child(title) of the current item in the list, and then get its text
    SuperText newST = new SuperText(linkText, color(255,0,0), 20, 20*i);  // create a new SuperText object using the title text, red color, a 20 x position and a y
                                                                          // y position that varies depending on how far into the list we are
    allText = (SuperText[])append(allText, newST);                        // store the new SuperText object in our array
  }
}

void draw() {
  background(0);
  if(allText != null) {                            // if our allText array is not empty (this forces Processing to wait until the rss/xml feed has been parsed)
    for(int i=0; i<allText.length; i++) {          // loop through all the items in our allText array
      allText[i].display();                        // and call the display method for each
    }
  }
}
